﻿using Microsoft.AspNetCore.Mvc;
using PaydayBackend.Models;
using PaydayBackend.Services;

namespace PaydayBackend.Controllers;

[Route("v1/public")]
[ApiController]
public class PublicController : ControllerBase
{
    private readonly IPublicService _publicService;

    public PublicController(IPublicService publicService)
    {
        _publicService = publicService;
    }

    /// <summary>
    /// Получение всех университетов
    /// </summary>
    [HttpGet("university")]
    public async Task<IEnumerable<University>> GetAllUniversity()
    {
          return await _publicService.GetAllUniversity();
    }
    
    /// <summary>
    /// Получение всех направлений университета
    /// </summary>
    /// <response code="400">Университет не найден</response>
    [HttpGet("university/{id}/direction")]
    public async Task<ActionResult<IEnumerable<University>>> GetAllUniversityDirectionByUniversityId(long id)
    {
          var result = await _publicService.GetAllUniversityDirectionByUniversityId(id);

          if (result == null)
              return BadRequest();
          
          return Ok(result);
    }
}